This crate contains kube-rs compatible bindings for Kubernetes custom resources for the argoproj.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
argoproj.io/v1alpha1
ApplicationApplicationSetAppProjectArgoCDExportArgoCD
argoproj.io/v1beta1
ArgoCD